function [ret,x0,str,ts,xts]=instable(t,x,u,flag);
%INSTABLE	is the M-file description of the SIMULINK system named INSTABLE.
%	The block-diagram can be displayed by typing: INSTABLE.
%
%	SYS=INSTABLE(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes INSTABLE to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling INSTABLE with a FLAG of zero:
%	[SIZES]=INSTABLE([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[100,100,1005,400])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'MATLAB Fcn','det_f_g(u)',...
		'Output Width','4',...
		'position',[370,126,490,184])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','+-',...
		'position',[255,119,290,186])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[140,125,160,145])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'mat-name','omega',...
		'buffer','points_trace',...
		'position',[400,87,450,103])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'position',[555,110,595,200])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'Value','2.12',...
		'position',[170,162,205,178])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[230,92,280,108])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','VP1',...
		'buffer','points_trace',...
		'position',[715,117,765,133])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','VP2',...
		'buffer','points_trace',...
		'position',[725,137,775,153])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'mat-name','delta',...
		'buffer','points_trace',...
		'position',[635,157,685,173])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'mat-name','produit',...
		'buffer','points_trace',...
		'position',[715,177,765,193])

add_block('built-in/Note',[sys,'/',['RECHERCHE DE L''INSTABILITE']])
set_param([sys,'/',['RECHERCHE DE L''INSTABILITE']],...
		'position',[365,30,370,35])
add_line(sys,[165,135;250,135])
add_line(sys,[210,170;250,170])
add_line(sys,[295,155;365,155])
add_line(sys,[495,155;550,155])
add_line(sys,[600,125;710,125])
add_line(sys,[320,155;320,95;395,95])
add_line(sys,[600,145;720,145])
add_line(sys,[200,135;200,100;225,100])
add_line(sys,[600,165;630,165])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
