function [ret,x0,str,ts,xts]=libresat(t,x,u,flag);
%LIBRESAT	is the M-file description of the SIMULINK system named LIBRESAT.
%	The block-diagram can be displayed by typing: LIBRESAT.
%
%	SYS=LIBRESAT(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes LIBRESAT to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling LIBRESAT with a FLAG of zero:
%	[SIZES]=LIBRESAT([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,77,1269,987])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     '20000')
set_param(sys,'Min step size', 'tsim/10000')
set_param(sys,'Max step size', 'tsim/1000')
set_param(sys,'Relative error','1e-4')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/','NANOSATELLITE CASAA-SAT'])
set_param([sys,'/','NANOSATELLITE CASAA-SAT'],...
		'Font Name','Arial',...
		'Font Size',24,...
		'position',[605,5,610,10])


%     Subsystem  'Subsystem5'.

new_system([sys,'/','Subsystem5'])
set_param([sys,'/','Subsystem5'],'Location',[29,301,546,866])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace7'])
set_param([sys,'/','Subsystem5/To Workspace7'],...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[320,312,370,328])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace5'])
set_param([sys,'/','Subsystem5/To Workspace5'],...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[240,507,290,523])

add_block('built-in/Clock',[sys,'/','Subsystem5/Clock'])
set_param([sys,'/','Subsystem5/Clock'],...
		'position',[120,505,140,525])


%     Subsystem  ['Subsystem5/Auto-Scale',13,'Graph'].

new_system([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']])
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Subsystem5/Auto-Scale',13,'Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Subsystem5/Auto-Scale',13,'Graph/x']])
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],[90,65;125,65])
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],...
		'Mask Entries','tsim*4\/-0.3\/0.3\/points_trace\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Subsystem5/Auto-Scale',13,'Graph'].

set_param([sys,'/',['Subsystem5/Auto-Scale',13,'Graph']],...
		'position',[335,345,365,385])

add_block('built-in/Inport',[sys,'/','Subsystem5/in_2'])
set_param([sys,'/','Subsystem5/in_2'],...
		'position',[15,275,35,295])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace11'])
set_param([sys,'/','Subsystem5/To Workspace11'],...
		'hide name',0,...
		'mat-name','vitesses',...
		'buffer','points_trace',...
		'position',[180,157,230,173])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace8'])
set_param([sys,'/','Subsystem5/To Workspace8'],...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[250,232,300,248])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace10'])
set_param([sys,'/','Subsystem5/To Workspace10'],...
		'hide name',0,...
		'mat-name','v_roulis',...
		'buffer','points_trace',...
		'position',[250,202,300,218])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace9'])
set_param([sys,'/','Subsystem5/To Workspace9'],...
		'hide name',0,...
		'mat-name','v_lacet',...
		'buffer','points_trace',...
		'position',[250,262,300,278])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux2'])
set_param([sys,'/','Subsystem5/Demux2'],...
		'hide name',0,...
		'outputs','3',...
		'position',[180,198,220,282])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux'])
set_param([sys,'/','Subsystem5/Demux'],...
		'hide name',0,...
		'outputs','[3,3]',...
		'position',[60,193,105,377])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux1'])
set_param([sys,'/','Subsystem5/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[175,403,215,487])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace2'])
set_param([sys,'/','Subsystem5/To Workspace2'],...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[240,407,290,423])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace4'])
set_param([sys,'/','Subsystem5/To Workspace4'],...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[245,467,295,483])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace3'])
set_param([sys,'/','Subsystem5/To Workspace3'],...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[240,437,290,453])


%     Subsystem  'Subsystem5/Subsystem'.

new_system([sys,'/','Subsystem5/Subsystem'])
set_param([sys,'/','Subsystem5/Subsystem'],'Location',[32,170,1037,769])

add_block('built-in/Gain',[sys,'/','Subsystem5/Subsystem/Gain1'])
set_param([sys,'/','Subsystem5/Subsystem/Gain1'],...
		'Gain','-1/2',...
		'position',[615,305,675,335])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem/Product3'])
set_param([sys,'/','Subsystem5/Subsystem/Product3'],...
		'position',[425,323,455,412])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum4'])
set_param([sys,'/','Subsystem5/Subsystem/Sum4'],...
		'hide name',0,...
		'position',[520,292,545,343])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem/Product2'])
set_param([sys,'/','Subsystem5/Subsystem/Product2'],...
		'position',[375,326,390,364])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem/Product'])
set_param([sys,'/','Subsystem5/Subsystem/Product'],...
		'position',[360,244,385,291])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem/Product1'])
set_param([sys,'/','Subsystem5/Subsystem/Product1'],...
		'position',[270,239,285,266])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem5/Subsystem/MATLAB Fcn'])
set_param([sys,'/','Subsystem5/Subsystem/MATLAB Fcn'],...
		'MATLAB Fcn','cinetic(Asat,u)',...
		'Output Width','1',...
		'position',[560,123,620,157])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem/energie',13,'cintique']])
set_param([sys,'/',['Subsystem5/Subsystem/energie',13,'cintique']],...
		'position',[660,145,665,150])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/E. M'])
set_param([sys,'/','Subsystem5/Subsystem/E. M'],...
		'position',[895,265,900,270])

add_block('built-in/Outport',[sys,'/','Subsystem5/Subsystem/Outport'])
set_param([sys,'/','Subsystem5/Subsystem/Outport'],...
		'position',[835,270,855,290])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem/CALCUL DE L''ENERGIE MECANIQUE']])
set_param([sys,'/',['Subsystem5/Subsystem/CALCUL DE L''ENERGIE MECANIQUE']],...
		'Font Name','Arial',...
		'Font Size',16,...
		'position',[480,5,485,10])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum5'])
set_param([sys,'/','Subsystem5/Subsystem/Sum5'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[775,252,800,303])

add_block('built-in/Constant',[sys,'/','Subsystem5/Subsystem/Constant2'])
set_param([sys,'/','Subsystem5/Subsystem/Constant2'],...
		'hide name',0,...
		'Value','3*(Il-It)',...
		'position',[65,371,260,409])

add_block('built-in/Constant',[sys,'/','Subsystem5/Subsystem/Constant3'])
set_param([sys,'/','Subsystem5/Subsystem/Constant3'],...
		'hide name',0,...
		'Value','3*(Ir-Il)',...
		'position',[60,291,255,329])

add_block('built-in/Inport',[sys,'/','Subsystem5/Subsystem/in_2'])
set_param([sys,'/','Subsystem5/Subsystem/in_2'],...
		'hide name',0,...
		'Port','2',...
		'position',[50,235,70,255])

add_block('built-in/Demux',[sys,'/','Subsystem5/Subsystem/Demux1'])
set_param([sys,'/','Subsystem5/Subsystem/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[150,207,200,283])

add_block('built-in/Inport',[sys,'/','Subsystem5/Subsystem/in_1'])
set_param([sys,'/','Subsystem5/Subsystem/in_1'],...
		'hide name',0,...
		'position',[55,105,75,125])

add_block('built-in/Demux',[sys,'/','Subsystem5/Subsystem/Demux'])
set_param([sys,'/','Subsystem5/Subsystem/Demux'],...
		'hide name',0,...
		'outputs','3',...
		'position',[105,58,150,172])

add_block('built-in/Gain',[sys,'/','Subsystem5/Subsystem/Gain'])
set_param([sys,'/','Subsystem5/Subsystem/Gain'],...
		'hide name',0,...
		'Gain','vitesse_rotation',...
		'position',[90,232,115,258])

add_block('built-in/Mux',[sys,'/','Subsystem5/Subsystem/Mux'])
set_param([sys,'/','Subsystem5/Subsystem/Mux'],...
		'hide name',0,...
		'inputs','3',...
		'position',[460,89,490,191])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum2'])
set_param([sys,'/','Subsystem5/Subsystem/Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[360,188,385,232])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum'])
set_param([sys,'/','Subsystem5/Subsystem/Sum'],...
		'hide name',0,...
		'position',[365,70,385,90])

add_block('built-in/Sum',[sys,'/','Subsystem5/Subsystem/Sum1'])
set_param([sys,'/','Subsystem5/Subsystem/Sum1'],...
		'hide name',0,...
		'position',[365,107,385,138])

add_block('built-in/Constant',[sys,'/','Subsystem5/Subsystem/Constant'])
set_param([sys,'/','Subsystem5/Subsystem/Constant'],...
		'hide name',0,...
		'Value','vitesse_rotation',...
		'position',[235,119,335,141])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/phi prime'])
set_param([sys,'/','Subsystem5/Subsystem/phi prime'],...
		'hide name',0,...
		'position',[270,45,275,50])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/teta prime'])
set_param([sys,'/','Subsystem5/Subsystem/teta prime'],...
		'hide name',0,...
		'position',[280,85,285,90])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/psi prime'])
set_param([sys,'/','Subsystem5/Subsystem/psi prime'],...
		'hide name',0,...
		'position',[295,175,300,180])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem/wo phi'])
set_param([sys,'/','Subsystem5/Subsystem/wo phi'],...
		'hide name',0,...
		'position',[275,215,280,220])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem/rotation',13,'absolue']])
set_param([sys,'/',['Subsystem5/Subsystem/rotation',13,'absolue']],...
		'hide name',0,...
		'position',[540,95,545,100])

add_block('built-in/Note',[sys,'/',['Subsystem5/Subsystem/energie potentielle',13,'du',13,'gradient']])
set_param([sys,'/',['Subsystem5/Subsystem/energie potentielle',13,'du',13,'gradient']],...
		'position',[635,355,640,360])
add_line([sys,'/','Subsystem5/Subsystem'],[460,370;505,370;515,330])
add_line([sys,'/','Subsystem5/Subsystem'],[390,270;480,270;480,305;515,305])
add_line([sys,'/','Subsystem5/Subsystem'],[265,390;420,390])
add_line([sys,'/','Subsystem5/Subsystem'],[395,345;420,345])
add_line([sys,'/','Subsystem5/Subsystem'],[205,220;355,220])
add_line([sys,'/','Subsystem5/Subsystem'],[315,220;315,335;370,335])
add_line([sys,'/','Subsystem5/Subsystem'],[330,335;330,355;370,355])
add_line([sys,'/','Subsystem5/Subsystem'],[290,255;355,255])
add_line([sys,'/','Subsystem5/Subsystem'],[205,245;265,245])
add_line([sys,'/','Subsystem5/Subsystem'],[240,245;240,260;265,260])
add_line([sys,'/','Subsystem5/Subsystem'],[625,140;720,140;720,265;770,265])
add_line([sys,'/','Subsystem5/Subsystem'],[495,140;555,140])
add_line([sys,'/','Subsystem5/Subsystem'],[805,280;830,280])
add_line([sys,'/','Subsystem5/Subsystem'],[680,320;750,320;750,290;770,290])
add_line([sys,'/','Subsystem5/Subsystem'],[550,320;610,320])
add_line([sys,'/','Subsystem5/Subsystem'],[260,310;335,310;335,280;355,280])
add_line([sys,'/','Subsystem5/Subsystem'],[75,245;85,245])
add_line([sys,'/','Subsystem5/Subsystem'],[80,115;100,115])
add_line([sys,'/','Subsystem5/Subsystem'],[155,75;360,75])
add_line([sys,'/','Subsystem5/Subsystem'],[205,270;220,270;220,85;360,85])
add_line([sys,'/','Subsystem5/Subsystem'],[120,245;145,245])
add_line([sys,'/','Subsystem5/Subsystem'],[155,115;360,115])
add_line([sys,'/','Subsystem5/Subsystem'],[340,130;360,130])
add_line([sys,'/','Subsystem5/Subsystem'],[155,155;250,155;250,200;355,200])
add_line([sys,'/','Subsystem5/Subsystem'],[390,80;405,80;405,105;455,105])
add_line([sys,'/','Subsystem5/Subsystem'],[390,125;430,125;430,140;455,140])
add_line([sys,'/','Subsystem5/Subsystem'],[390,210;430,210;430,175;455,175])
set_param([sys,'/','Subsystem5/Subsystem'],...
		'Mask Display','ENERGIE')


%     Finished composite block 'Subsystem5/Subsystem'.

set_param([sys,'/','Subsystem5/Subsystem'],...
		'hide name',0,...
		'position',[165,302,270,338])
add_line([sys,'/','Subsystem5'],[145,515;235,515])
add_line([sys,'/','Subsystem5'],[110,330;160,330])
add_line([sys,'/','Subsystem5'],[150,330;150,445;170,445])
add_line([sys,'/','Subsystem5'],[150,365;330,365])
add_line([sys,'/','Subsystem5'],[40,285;55,285])
add_line([sys,'/','Subsystem5'],[220,415;235,415])
add_line([sys,'/','Subsystem5'],[220,445;235,445])
add_line([sys,'/','Subsystem5'],[220,475;240,475])
add_line([sys,'/','Subsystem5'],[110,240;175,240])
add_line([sys,'/','Subsystem5'],[140,240;140,310;160,310])
add_line([sys,'/','Subsystem5'],[225,210;245,210])
add_line([sys,'/','Subsystem5'],[225,240;245,240])
add_line([sys,'/','Subsystem5'],[225,270;245,270])
add_line([sys,'/','Subsystem5'],[140,240;140,165;175,165])
add_line([sys,'/','Subsystem5'],[275,320;315,320])
set_param([sys,'/','Subsystem5'],...
		'Mask Display','SORTIES DES VARIABLES\n\nENERGIE')


%     Finished composite block 'Subsystem5'.

set_param([sys,'/','Subsystem5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'position',[960,272,1235,378])

add_block('built-in/Note',[sys,'/','(Avec les quations TMC Garino-Guiziou )'])
set_param([sys,'/','(Avec les quations TMC Garino-Guiziou )'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[780,590,785,595])

add_block('built-in/Note',[sys,'/','6 variables=3 vitesses( 1  3)+3 angles(4  6)'])
set_param([sys,'/','6 variables=3 vitesses( 1  3)+3 angles(4  6)'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[425,590,430,595])

add_block('built-in/State-Space',[sys,'/','State-space'])
set_param([sys,'/','State-space'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'A','A_SIM(Asat,K_SAT,H_SAT,L_SAT,Q_SAT,vitesseroue)',...
		'B','B_SIM(Asat,K_SAT,H_SAT,L_SAT,Q_SAT)',...
		'C','eye(6)',...
		'D','zeros(6,3)')
set_param([sys,'/','State-space'],...
		'X0','[0 0 0 0.1 -0.1 -0.05]''',...
		'Mask Display','MODELE\nSATELLITE',...
		'position',[780,298,895,352])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[277,588,777,802])

add_block('built-in/Inport',[sys,'/','Subsystem1/Inport'])
set_param([sys,'/','Subsystem1/Inport'],...
		'position',[50,80,70,100])


%     Subsystem  ['Subsystem1/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],'Location',[-86,133,1181,689])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[1025,53,1055,157])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[835,58,980,82])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[835,93,980,117])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[835,128,980,152])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[935,165,940,170])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[1015,213,1045,317])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[825,218,970,242])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[825,253,970,277])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[825,288,970,312])

add_block('built-in/Sum',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','+++',...
		'position',[1130,214,1165,316])

add_block('built-in/Outport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/out_1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/out_1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'position',[1200,255,1220,275])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/B']],...
		'position',[560,385,565,390])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/M']],...
		'position',[565,285,570,290])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[170,333,315,357])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[170,298,315,322])

add_block('built-in/Constant',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[170,263,315,287])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[360,258,390,362])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Vitesses',13,'inutiles']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Vitesses',13,'inutiles']],...
		'position',[190,380,195,385])

add_block('built-in/Inport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[50,450,70,470])

add_block('built-in/Demux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Demux4']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Demux4']],...
		'hide name',0,...
		'outputs','[3 1 1 1]',...
		'position',[95,380,140,540])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Tangage']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Tangage']],...
		'position',[175,455,180,460])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Roulis']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Roulis']],...
		'position',[170,415,175,420])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Lacet']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Lacet']],...
		'position',[165,495,170,500])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux4']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux4']],...
		'inputs','3',...
		'position',[225,424,265,506])


%     Subsystem  ['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,367,1041,836])


%     Subsystem  ['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

new_system([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],'Location',[27,258,1102,698])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']],...
		'position',[804,170,809,175])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']],...
		'position',[804,290,809,295])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']],...
		'position',[715,325,720,330])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[910,170,915,175])

add_block('built-in/Outport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']],...
		'position',[965,230,985,250])

add_block('built-in/State-Space',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Display','Axe x',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Entries','[0 0 0;0 0 -1;0 1 0]\/',...
		'position',[415,93,470,127])

add_block('built-in/Demux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']],...
		'outputs','3',...
		'position',[520,44,580,76])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,100,565,135])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']],...
		'position',[784,215,789,220])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']],...
		'hide name',0,...
		'inputs','3',...
		'position',[820,220,865,260])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']],...
		'position',[730,205,735,210])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']],...
		'position',[740,75,745,80])

add_block('built-in/Sum',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']],...
		'hide name',0,...
		'position',[755,95,775,130])

add_block('built-in/State-Space',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Display','Axe y',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Entries','[0 0 1;0 0 0;-1 0 0]\/',...
		'position',[415,223,470,257])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,230,565,265])

add_block('built-in/Sum',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']],...
		'hide name',0,...
		'position',[755,220,770,260])

add_block('built-in/Sum',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']],...
		'hide name',0,...
		'position',[755,339,790,381])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'position',[615,349,675,391])

add_block('built-in/State-Space',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Display','Axe z',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Entries','[0 -1 0 ;1 0 0 ;0 0 0]\/')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'position',[415,338,470,372])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[540,344,570,391])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']],...
		'position',[439,145,444,150])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'position',[600,104,665,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'position',[590,234,665,266])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[305,25,310,30])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']],...
		'position',[85,65,90,70])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'position',[180,85,355,135])

add_block('built-in/Clock',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']],...
		'position',[115,100,135,120])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']],...
		'position',[273,165,278,170])

add_block('built-in/Inport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']],...
		'position',[120,160,140,180])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[795,360;795,255;815,255])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[780,115;795,115;795,225;815,225])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,50;720,50;720,105;750,105])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,60;705,60;705,230;750,230])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,70;690,70;690,350;750,350])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[360,110;410,110])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,60;515,60])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[775,240;815,240])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,355;410,355])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,240;410,240])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[145,170;510,170;510,125;530,125])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,170;510,380;535,380])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,255;530,255])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[680,370;750,370])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,355;535,355])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[575,370;610,370])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,250;585,250])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,240;530,240])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,250;750,250])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,120;750,120])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,110;530,110])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,120;595,120])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[870,240;960,240])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[140,110;175,110])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[405,84,540,156])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Angles']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Angles']],...
		'position',[350,135,355,140])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[660,150,665,155])

add_block('built-in/Inport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[285,110,305,130])

add_block('built-in/Outport',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[615,110,635,130])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']],...
		'position',[305,160,310,165])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[460,30,465,35])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[545,120;610,120])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[310,120;400,120])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[290,428,490,502])

add_block('built-in/Mux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[580,256,625,474])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[680,348,740,382])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[465,40,470,45])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[285,216,290,221])

add_block('built-in/Demux',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Demux5']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Demux5']],...
		'hide name',0,...
		'outputs','[3 1 1 1]',...
		'position',[25,380,70,540])

add_block('built-in/To Workspace',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[935,410,1055,440])

add_block('built-in/Gain',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[415,285,530,335])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[810,408,870,442])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[730,247,735,252])

add_block('built-in/Note',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[920,369,925,374])

add_block('built-in/Gain',[sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[840,352,875,378])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[1060,105;1115,105;1125,230])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[1170,265;1195,265])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[975,300;1010,300])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[1050,265;1125,265])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[975,265;1010,265])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[975,230;1010,230])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[985,140;1020,140])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[985,105;1020,105])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[985,70;1020,70])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[320,345;355,345])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[320,310;355,310])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[320,275;355,275])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[395,310;410,310])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[535,310;575,310])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[270,465;285,465])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[145,440;220,440])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[145,480;205,480;205,465;220,465])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[145,520;185,520;185,490;220,490])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[75,460;90,460])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[495,465;510,465;510,420;575,420])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[630,365;675,365])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[745,365;775,365;775,425;805,425])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[875,425;930,425])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[775,365;835,365])
add_line([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],[880,365;1095,365;1095,300;1125,300])
set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['Subsystem1/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['Subsystem1/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[100,62,230,118])

add_block('built-in/Gain',[sys,'/','Subsystem1/Gain3'])
set_param([sys,'/','Subsystem1/Gain3'],...
		'hide name',0,...
		'position',[270,77,305,103])

add_block('built-in/Outport',[sys,'/','Subsystem1/out_1'])
set_param([sys,'/','Subsystem1/out_1'],...
		'position',[410,80,430,100])

add_block('built-in/To Workspace',[sys,'/','Subsystem1/To Workspace10'])
set_param([sys,'/','Subsystem1/To Workspace10'],...
		'hide name',0,...
		'mat-name','cpl_pert',...
		'buffer','points_trace',...
		'position',[375,50,480,70])
add_line([sys,'/','Subsystem1'],[235,90;265,90])
add_line([sys,'/','Subsystem1'],[310,90;405,90])
add_line([sys,'/','Subsystem1'],[75,90;95,90])
add_line([sys,'/','Subsystem1'],[340,90;340,60;370,60])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','3 - PERTURBATIONS\n\nFournir la direction\ndu moment rsiduel')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[220,289,570,361])

add_block('built-in/Note',[sys,'/',['Retour d''tat']])
set_param([sys,'/',['Retour d''tat']],...
		'position',[395,565,400,570])

add_block('built-in/Gain',[sys,'/','Gain5'])
set_param([sys,'/','Gain5'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Gain','0',...
		'position',[655,312,690,338])

add_block('built-in/Note',[sys,'/','U'])
set_param([sys,'/','U'],...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[610,295,615,300])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\n\nvitesses angulaires (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,v_roulis,temps,v_tangage,temps,v_lacet);grid;'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[55,760,260,821])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir les courbes\ncouple \nperturbateurs (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_pert);grid;'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[50,830,260,891])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=bleu\nlacet=magenta')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[270,735,500,821])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\n\ndes angles',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[50,690,255,756])


%     Subsystem  'Extras14'.

new_system([sys,'/','Extras14'])
set_param([sys,'/','Extras14'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras14'],...
		'Mask Display','Vitesse roue\n\n6000 tours/mn',...
		'Mask Dialogue','eval(''vitesseroue=100*2*pi;'')')


%     Finished composite block 'Extras14'.

set_param([sys,'/','Extras14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1085,690,1265,751])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Vitesse roue\n\n1200 tours/mn',...
		'Mask Dialogue','eval(''vitesseroue=20*2*pi;'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[885,690,1070,751])


%     Subsystem  'Extras13'.

new_system([sys,'/','Extras13'])
set_param([sys,'/','Extras13'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras13'],...
		'Mask Display','Vitesse roue ngative\n\n1200 tours/mn',...
		'Mask Dialogue','eval(''vitesseroue=-20*2*pi;'')')


%     Finished composite block 'Extras13'.

set_param([sys,'/','Extras13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,850,1060,911])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Vitesse roue ngative\n\n6000 tours/mn',...
		'Mask Dialogue','eval(''vitesseroue=-100*2*pi;'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1080,850,1265,911])


%     Subsystem  'Extras15'.

new_system([sys,'/','Extras15'])
set_param([sys,'/','Extras15'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras15'],...
		'Mask Display','Vitesse roue n\n1 tour/mn',...
		'Mask Dialogue','eval(''vitesseroue=1*2*pi;'')')


%     Finished composite block 'Extras15'.

set_param([sys,'/','Extras15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,695,690,756])


%     Subsystem  'Extras16'.

new_system([sys,'/','Extras16'])
set_param([sys,'/','Extras16'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras16'],...
		'Mask Display','Vitesse roue n\n5 tours/mn',...
		'Mask Dialogue','eval(''vitesseroue=5*2*pi;'')')


%     Finished composite block 'Extras16'.

set_param([sys,'/','Extras16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[705,695,880,756])


%     Subsystem  'Extras12'.

new_system([sys,'/','Extras12'])
set_param([sys,'/','Extras12'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras12'],...
		'Mask Display','Vitesse roue ngative\n\n1 tour/mn',...
		'Mask Dialogue','eval(''vitesseroue=-1*2*pi;'')')


%     Finished composite block 'Extras12'.

set_param([sys,'/','Extras12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,830,690,891])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras2'],...
		'Mask Display','1 - INITIALISATION\n\npar double clic souris',...
		'Mask Dialogue','eval(''libredat'')')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[985,400,1185,501])

add_block('built-in/Note',[sys,'/',['2- Choisir une vitesse',13,' de la roue',13,'',13,'3 -  Lancer la simulation']])
set_param([sys,'/',['2- Choisir une vitesse',13,' de la roue',13,'',13,'3 -  Lancer la simulation']],...
		'Font Name','Arial',...
		'Font Size',16,...
		'position',[1095,510,1100,515])

add_block('built-in/Note',[sys,'/',['Simulation  ==>  nom lecteur://......//libresat.m',13,'',13,' initialise obligatoirement  chaque simulation  par  nom lecteur://......//libredat.m',13,' ( opration double click avant dpart de la simulation )',13,' ']])
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//libresat.m',13,'',13,' initialise obligatoirement  chaque simulation  par  nom lecteur://......//libredat.m',13,' ( opration double click avant dpart de la simulation )',13,' ']],...
		'ForeGround',4)
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//libresat.m',13,'',13,' initialise obligatoirement  chaque simulation  par  nom lecteur://......//libredat.m',13,' ( opration double click avant dpart de la simulation )',13,' ']],...
		'Font Name','Arial')
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//libresat.m',13,'',13,' initialise obligatoirement  chaque simulation  par  nom lecteur://......//libredat.m',13,' ( opration double click avant dpart de la simulation )',13,' ']],...
		'Font Weight','bold')
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//libresat.m',13,'',13,' initialise obligatoirement  chaque simulation  par  nom lecteur://......//libredat.m',13,' ( opration double click avant dpart de la simulation )',13,' ']],...
		'Font Size',14)
set_param([sys,'/',['Simulation  ==>  nom lecteur://......//libresat.m',13,'',13,' initialise obligatoirement  chaque simulation  par  nom lecteur://......//libredat.m',13,' ( opration double click avant dpart de la simulation )',13,' ']],...
		'position',[550,430,555,435])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Vitesse roue\n\nnulle',...
		'Mask Dialogue','eval(''vitesseroue=0;'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,760,695,821])

add_block('built-in/Note',[sys,'/','Tous les couples intervenants'])
set_param([sys,'/','Tous les couples intervenants'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[820,250,825,255])

add_block('built-in/Note',[sys,'/',['SYSTEME LIBRE AVEC GRADIENT PRINCIPAL',13,'ET LA ROUE SIMPLEMENT EN ROTATION',13,'( NON UTULISEE EN REGULATION']])
set_param([sys,'/',['SYSTEME LIBRE AVEC GRADIENT PRINCIPAL',13,'ET LA ROUE SIMPLEMENT EN ROTATION',13,'( NON UTULISEE EN REGULATION']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16)
set_param([sys,'/',['SYSTEME LIBRE AVEC GRADIENT PRINCIPAL',13,'ET LA ROUE SIMPLEMENT EN ROTATION',13,'( NON UTULISEE EN REGULATION']],...
		'position',[595,50,600,55])


%     Subsystem  'Extras17'.

new_system([sys,'/','Extras17'])
set_param([sys,'/','Extras17'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras17'],...
		'Mask Display','Vitesse roue qui donne une instabilit ???\n\nde -1.8103 rd/s (-17.3 tr/mn)  - 0.12931 rd/s (-1.23 tr/mn)',...
		'Mask Dialogue','eval(''vitesseroue=-1.75;'')')


%     Finished composite block 'Extras17'.

set_param([sys,'/','Extras17'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[710,745,1260,836])
add_line(sys,[695,325;775,325])
add_line(sys,[900,325;920,325;920,590;145,590;145,325;215,325])
add_line(sys,[575,325;650,325])
add_line(sys,[920,325;955,325])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
